@@ -38,12 +38,26 @@ class SalesforceModelBase(ModelBase):
 	and replaces it with code that defaults to the model name.
 	"""
 	def __new__(cls, name, bases, attrs):
-		supplied_db_table = getattr(attrs.get('Meta', None), 'db_table', None)
+		attr_meta = attrs.get('Meta', None)
+		supplied_db_table = getattr(attr_meta, 'db_table', None)
+		if hasattr(attr_meta, 'sf_pk'):
+			cls.sf_pk = attr_meta.sf_pk
 		result = super(SalesforceModelBase, cls).__new__(cls, name, bases, attrs)
 		if(models.Model not in bases and supplied_db_table is None):
 			result._meta.db_table = name
 		return result
 
+	def add_to_class(cls, name, value):
+		if name == '_meta':
+			sf_custom = False
+			if hasattr(value.meta, 'custom'):
+				sf_custom = value.meta.custom
+				delattr(value.meta, 'custom')
+			super(SalesforceModelBase, cls).add_to_class(name, value)
+			setattr(cls._meta, 'sf_custom', sf_custom)
+		else:
+			super(SalesforceModelBase, cls).add_to_class(name, value)
+
 
 # Backported for Django 1.4 from django.utils.six version 1.7
 def with_metaclass(meta, *bases):
